.. the "raw" directive below is used to hide the title in favor of
   just the logo being visible
.. .. raw:: html

..     <style media="screen" type="text/css">
..       h1 {display:none;}
..     </style>

.. .. |br| raw:: html

..     <div style="min-height:0.1em;"></div>

*********
AstroPhot
*********

.. .. image:: https://github.com/Autostronomy/AstroPhot/blob/main/media/AP_logo.png?raw=true
..    :width: 100 %
..    :target: https://github.com/Autostronomy/AstroPhot


.. Important::
    If you use AstroPhot for a project that leads to a publication,
    whether directly or as a dependency of another package, please
    include a :doc:`citation <citation>`.


Getting Started
===============

AstroPhot is a fast, flexible, and automated astronomical image modelling tool
for precise parallel multi-wavelength photometry. Its pythonic design allows for
fast startup and provides flexibility to explore new ideas and support advanced
users. It was written by `Connor Stone <https://connorjstone.com/>`_ .

To install AstroPhot, use pip:

.. code-block:: bash

    pip install astrophot

To just get started on a fit, download a quick-start file from: :doc:`fastfit`.

Check out the tutorials to learn how to use AstroPhot in detail: :doc:`tutorials/index`.

If you run into any problems, please submit an issue on the `GitHub page
<https://github.com/Autostronomy/AstroPhot>`_ or just email me.

.. note::

    Like much astronomy software, AstroPhot is an evolving package. I try to
    keep the API stable and consistent, however I will make changes to the
    interface if it considerably improves things going forward. Please contact
    connorstone628@gmail.com if you experience issues. If you would like to be
    notified of major changes send an email with the subject line "ASTROPHOT
    MAILING LIST".
